@@ -13,25 +13,25 @@ use Scalar::Util 'weaken';
 use constant DEBUG => $ENV{MOJO_USERAGENT_DEBUG} || 0;
 
 # "You can't let a single bad experience scare you away from drugs."
-has ca   => sub { $ENV{MOJO_CA_FILE} };
-has cert => sub { $ENV{MOJO_CERT_FILE} };
-has connect_timeout => 3;
-has cookie_jar => sub { Mojo::CookieJar->new };
+has ca              => sub { $ENV{MOJO_CA_FILE} };
+has cert            => sub { $ENV{MOJO_CERT_FILE} };
+has connect_timeout => sub { $ENV{MOJO_CONNECT_TIMEOUT} || 10 };
+has cookie_jar      => sub { Mojo::CookieJar->new };
 has [qw/http_proxy https_proxy local_address no_proxy/];
-has inactivity_timeout => 20;
+has inactivity_timeout => sub { $ENV{MOJO_INACTIVITY_TIMEOUT} // 20 };
 has ioloop             => sub { Mojo::IOLoop->new };
 has key                => sub { $ENV{MOJO_KEY_FILE} };
 has max_connections    => 5;
-has max_redirects      => sub { $ENV{MOJO_MAX_REDIRECTS} || 0 };
-has name               => 'Mojolicious (Perl)';
-has request_timeout    => 0;
-has transactor => sub { Mojo::UserAgent::Transactor->new };
-has websocket_timeout => 300;
+has max_redirects => sub { $ENV{MOJO_MAX_REDIRECTS} || 0 };
+has name => 'Mojolicious (Perl)';
+has request_timeout   => sub { $ENV{MOJO_REQUEST_TIMEOUT}   // 0 };
+has transactor        => sub { Mojo::UserAgent::Transactor->new };
+has websocket_timeout => sub { $ENV{MOJO_WEBSOCKET_TIMEOUT} // 300 };
 
 # Common HTTP methods
 {
   no strict 'refs';
-  for my $name (qw/DELETE GET HEAD POST PUT/) {
+  for my $name (qw/DELETE GET HEAD PATCH POST PUT/) {
     *{__PACKAGE__ . '::' . lc($name)} = sub {
       my $self = shift;
       $self->start($self->build_tx($name, @_));
@@ -261,6 +261,7 @@ sub _connect_proxy {
         return $loop->client(
           handle   => $handle,
           id       => $id,
+          timeout  => $self->connect_timeout,
           tls      => 1,
           tls_ca   => $self->ca,
           tls_cert => $self->cert,
@@ -631,7 +632,9 @@ L<Mojo::UserAgent> is a full featured non-blocking I/O HTTP 1.1 and WebSocket
 user agent with C<IPv6>, C<TLS> and C<libev> support.
 
 Optional modules L<EV>, L<IO::Socket::IP> and L<IO::Socket::SSL> are
-supported transparently and used if installed.
+supported transparently and used if installed. Individual features can also
+be disabled with the C<MOJO_NO_IPV6> and C<MOJO_NO_TLS> environment
+variables.
 
 =head1 EVENTS
 
@@ -697,7 +700,8 @@ environment variable.
   $ua         = $ua->connect_timeout(5);
 
 Maximum amount of time in seconds establishing a connection may take before
-getting canceled, defaults to C<3>.
+getting canceled, defaults to the value of the C<MOJO_CONNECT_TIMEOUT>
+environment variable or C<10>.
 
 =head2 C<cookie_jar>
 
@@ -727,8 +731,9 @@ Proxy server to use for HTTPS and WebSocket requests.
   $ua         = $ua->inactivity_timeout(15);
 
 Maximum amount of time in seconds a connection can be inactive before getting
-dropped, defaults to C<20>. Setting the value to C<0> will allow connections
-to be inactive indefinitely.
+dropped, defaults to the value of the C<MOJO_INACTIVITY_TIMEOUT> environment
+variable or C<20>. Setting the value to C<0> will allow connections to be
+inactive indefinitely.
 
 =head2 C<ioloop>
 
@@ -792,7 +797,8 @@ Domains that don't require a proxy server to be used.
 
 Maximum amount of time in seconds establishing a connection, sending the
 request and receiving a whole response may take before getting canceled,
-defaults to C<0>. Setting the value to C<0> will allow the user agent to wait
+defaults to the value of the C<MOJO_REQUEST_TIMEOUT> environment variable or
+C<0>. Setting the value to C<0> will allow the user agent to wait
 indefinitely. The timeout will reset for every followed redirect. Note that
 this attribute is EXPERIMENTAL and might change without warning!
 
@@ -813,8 +819,9 @@ Note that this attribute is EXPERIMENTAL and might change without warning!
   $ua         = $ua->websocket_timeout(300);
 
 Maximum amount of time in seconds a WebSocket connection can be inactive
-before getting dropped, defaults to C<300>. Setting the value to C<0> will
-allow WebSocket connections to be inactive indefinitely.
+before getting dropped, defaults to the value of the
+C<MOJO_WEBSOCKET_TIMEOUT> environment variable or C<300>. Setting the value
+to C<0> will allow WebSocket connections to be inactive indefinitely.
 
 =head1 METHODS
 
@@ -885,7 +892,8 @@ append a callback to perform requests non-blocking.
   $ua = $ua->detect_proxy;
 
 Check environment variables C<HTTP_PROXY>, C<http_proxy>, C<HTTPS_PROXY>,
-C<https_proxy>, C<NO_PROXY> and C<no_proxy> for proxy information.
+C<https_proxy>, C<NO_PROXY> and C<no_proxy> for proxy information. Automatic
+proxy detection can be enabled with the C<MOJO_PROXY> environment variable.
 
 =head2 C<get>
 
@@ -925,6 +933,23 @@ append a callback to perform requests non-blocking.
 
 Check if request for domain would use a proxy server.
 
+=head2 C<patch>
+
+  my $tx = $ua->patch('http://kraih.com');
+
+Perform blocking HTTP C<PATCH> request and return resulting
+L<Mojo::Transaction::HTTP> object, takes the exact same arguments as
+L<Mojo::UserAgent::Transactor/"tx"> (except for the method). You can also
+append a callback to perform requests non-blocking. Note that this method is
+EXPERIMENTAL and might change without warning!
+
+  $ua->patch('http://kraih.com' => sub {
+    my ($ua, $tx) = @_;
+    say $tx->res->body;
+    Mojo::IOLoop->stop;
+  });
+  Mojo::IOLoop->start;
+
 =head2 C<post>
 
   my $tx = $ua->post('http://kraih.com');
