@@ -32,8 +32,8 @@ our $DEV_NOT_FOUND = $H->slurp_rel_file('not_found.development.html.ep');
 
 # Reserved stash values
 my @RESERVED = (
-  qw/action app cb class controller data exception extends format handler/,
-  qw/json layout method namespace partial path status template text/
+  qw/action app cb controller data extends format handler json layout/,
+  qw/namespace partial path status template text/
 );
 my %RESERVED;
 $RESERVED{$_}++ for @RESERVED;
@@ -354,11 +354,10 @@ sub render_static {
   my ($self, $file) = @_;
 
   my $app = $self->app;
-  unless ($app->static->serve($self, $file)) {
-    $app->log->debug(
-      qq/Static file "$file" not found, public directory missing?/);
-    return;
-  }
+  $app->log->debug(
+    qq/Static file "$file" not found, public directory missing?/)
+    and return
+    unless $app->static->serve($self, $file);
   $self->rendered;
 
   return 1;
@@ -962,7 +961,11 @@ Cookies failing signature verification will be automatically discarded.
   $c        = $c->stash(foo => 'bar');
 
 Non persistent data storage and exchange, application wide default values can
-be set with L<Mojolicious/"defaults">.
+be set with L<Mojolicious/"defaults">. Many stash value have a special
+meaning and are reserved, the full list is currently C<action>, C<app>,
+C<cb>, C<controller>, C<data>, C<extends>, C<format>, C<handler>, C<json>,
+C<layout>, C<namespace>, C<partial>, C<path>, C<status>, C<template> and
+C<text>.
 
   $c->stash->{foo} = 'bar';
   my $foo = $c->stash->{foo};
